==> kdemultimedia-3.0.1.tar.bz2: kdemultimedia-3.0.1/kaboodle/kaboodle_factory.h <==
/*****************************************************************

Copyright (c) 2000-2001 the noatun authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIAB\ILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef KABOODLE_FACTORY_H
#define KABOODLE_FACTORY_H

#include <kinstance.h>
#include <kaboutdata.h>
#include <klibloader.h>
#include <kparts/browserextension.h>

class KaboodleFactory : public KLibFactory					
{
Q_OBJECT

public:
	KaboodleFactory();
	virtual ~KaboodleFactory();

	virtual QObject* createObject(QObject *parent = 0, const char *name = 0, const char *classname = "QObject", const QStringList &args = QStringList());

	static const KAboutData *aboutData();
	static KInstance *instance();
	
private:
	static KInstance *s_instance;
};

class KaboodleBrowserExtension : public KParts::BrowserExtension
{
Q_OBJECT
friend class KaboodlePart;

public:
	KaboodleBrowserExtension(KaboodlePart *parent);
	virtual ~KaboodleBrowserExtension();
};

#endif

==> kdemultimedia-3.0.3.tar.bz2: kdemultimedia-3.0.3/kaboodle/kaboodle_factory.h <==
/*****************************************************************

Copyright (c) 2000-2001 the noatun authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIAB\ILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef KABOODLE_FACTORY_H
#define KABOODLE_FACTORY_H

#include <kinstance.h>
#include <kaboutdata.h>
#include <klibloader.h>
#include <kparts/browserextension.h>
#include <kparts/factory.h>

class KaboodleFactory : public KParts::Factory
{
Q_OBJECT

public:
	KaboodleFactory();
	virtual ~KaboodleFactory();

	virtual KParts::Part *KaboodleFactory::createPartObject(QWidget *widgetParent, const char *widgetName, QObject *parent, const char *name, const char *className, const QStringList &);

	static const KAboutData *aboutData();
	static KInstance *instance();
	
private:
	static KInstance *s_instance;
	static KAboutData *s_aboutData;
};

class KaboodleBrowserExtension : public KParts::BrowserExtension
{
Q_OBJECT
friend class KaboodlePart;

public:
	KaboodleBrowserExtension(KaboodlePart *parent);
	virtual ~KaboodleBrowserExtension();
};

#endif
